#include "device.h"
#include "system.h"

void EnableM4MasterTrigger(void);
void EnableCrosstrigger(void);
void Init_MBOX(void);

   #define MBOX0_PORT1_MEM             0x400dC000                                   // Base address of MBOX Port1 Memory
   #define ptr_MBOX0_PORT1_MEM                                                        ((volatile unsigned int*)MBOX0_PORT1_MEM)   

   unsigned int *pREG_CTI1_LAR          = (unsigned int *)0xE0049FB0;	/*  CTI1 CTI Access Control Register */
   unsigned int *pREG_CTI1_CTICONTROL   = (unsigned int *)0xE0049000;	/*  CTI1 CTI Control Register */
   unsigned int *pREG_CTI1_CTIINEN0     = (unsigned int *)0xE0049020;	/*  CTI1 CTI Trigger 0 to Channel Enable Register */
   unsigned int *pREG_CTI1_CTIOUTEN7    = (unsigned int *)0xE00490BC;	/*  CTI1 CTI Channel to Trigger 7 Enable Register */
   unsigned int *pREG_CTI1_CTIOUTEN0    = (unsigned int *)0xE00490A0;	/*  CTI1 CTI Channel to Trigger 0 Enable Register */

   unsigned int *pREG_CTI0_LAR          = (unsigned int *)0xE0048FB0;	/*  CTI0 CTI Access Control Register */
   unsigned int *pREG_CTI0_CTICONTROL 	= (unsigned int *)0xE0048000;	/*  CTI0 CTI Control Register */
   unsigned int *pREG_CTI0_CTIINEN0	= (unsigned int *)0xE0048020;	/*  CTI0 CTI Trigger 0 to Channel Enable Register */
   unsigned int *pREG_CTI0_CTIINEN6     = (unsigned int *)0xE0048038;   /*  CTI0 CTI Trigger 6 to Channel Enable Register */
   unsigned int *pREG_CTI0_CTIINEN7     = (unsigned int *)0xE004803C;   /*  CTI0 CTI Trigger 7 to Channel Enable Register */
   unsigned int *pREG_CTI0_CTIOUTEN0	= (unsigned int *)0xE00480A0;	/*  CTI0 CTI Channel to Trigger 0 Enable Register */
   unsigned int *pREG_CTI0_CTIOUTEN6    = (unsigned int *)0xE00480B8;   /*  CTI0 CTI Channel to Trigger 6 Enable Register */
   unsigned int *pREG_CTI0_CTIOUTEN7    = (unsigned int *)0xE00480BC;   /*  CTI0 CTI Channel to Trigger 7 Enable Register */

   unsigned int *pREG_CTI3_LAR          = (unsigned int *)0xE004BFB0;	/*  CTI3 CTI Access Control Register */
   unsigned int *pREG_CTI3_CTICONTROL   = (unsigned int *)0xE004B000;	/*  CTI3 CTI Control Register */
   unsigned int *pREG_CTI3_CTIINEN0     = (unsigned int *)0xE004B020;	/*  CTI3 CTI Trigger 0 to Channel Enable Register */
   unsigned int *pREG_CTI3_CTIINEN1     = (unsigned int *)0xE004B024;	/*  CTI3 CTI Trigger 1 to Channel Enable Register */
   unsigned int *pREG_CTI3_CTIINEN2     = (unsigned int *)0xE004B028;	/*  CTI3 CTI Trigger 2 to Channel Enable Register */
   unsigned int *pREG_CTI3_CTIOUTEN0    = (unsigned int *)0xE004B0A0;	/*  CTI3 CTI Channel to Trigger 0 Enable Register */
   unsigned int *pREG_CTI3_CTIOUTEN1    = (unsigned int *)0xE004B0A4;	/*  CTI3 CTI Channel to Trigger 1 Enable Register */
   unsigned int *pREG_CTI3_CTIOUTEN2    = (unsigned int *)0xE004B0A8;	/*  CTI3 CTI Channel to Trigger 2 Enable Register */
     

int main()
{
  //System Init
  SystemInit();
  
  //Confgure cross trigger
  EnableCrosstrigger();
  
  //Enable the trigger to GRP
  EnableM4MasterTrigger();
  
  //Initialize MBOX
  Init_MBOX();
  
  //wait
  while(1)
  {
    asm("NOP;");
    asm("NOP;");
  }
  
  
  return 0;
}

void Init_MBOX()
{
  *pREG_MBOX0_PORT1_CTL  |= BITM_MBOX_PORT1_CTL_INIT;
   while(!*pREG_MBOX0_PORT1_STAT & BITM_MBOX_PORT1_STAT_INITDONE);

  *pREG_MBOX0_PORT1_STAT |= BITM_MBOX_PORT1_STAT_INITDONE;

}

void EnableM4MasterTrigger()
{
  *pREG_TRU1_GCTL       = 0x1; asm("DSB;");
  *pREG_TRU1_SSR103     = TRGM_CTI3_MST2; asm("DSB;");
}

void EnableCrosstrigger()
{
  *pREG_CTI0_LAR=0xC5ACCE55; asm("DSB;");
  *pREG_CTI0_CTICONTROL = 0x00000001;
  *pREG_CTI0_CTIINEN0 = 0x00000001;
  *pREG_CTI0_CTIINEN6 = 0x00000001;
  *pREG_CTI0_CTIINEN7 = 0x00000001;
  *pREG_CTI0_CTIOUTEN0 = 0x00000001;
  *pREG_CTI0_CTIOUTEN6 = 0x00000002;
  *pREG_CTI0_CTIOUTEN7 = 0x00000000;
  
  *pREG_CTI3_LAR=0xC5ACCE55; asm("DSB;");
  *pREG_CTI3_CTICONTROL = 0x00000001;
  *pREG_CTI3_CTIINEN0 = 0x00000001;
  *pREG_CTI3_CTIINEN1 = 0x00000001;
  *pREG_CTI3_CTIINEN2 = 0x00000001;
  *pREG_CTI3_CTIOUTEN0 = 0x00000001;
  *pREG_CTI3_CTIOUTEN1 = 0x00000001;
  *pREG_CTI3_CTIOUTEN2 = 0x00000001;   
  
  *pREG_CTI1_LAR=0xC5ACCE55; asm("DSB;");
  *pREG_CTI1_CTICONTROL = 0x00000001;
  *pREG_CTI1_CTIINEN0 = 0x00000001;
  *pREG_CTI1_CTIOUTEN7 = 0x00000002;
  *pREG_CTI1_CTIOUTEN0 = 0x00000001;
}

 